==> haskell-tasty-lua-0.2.0.1-1-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-tasty-lua.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: tasty-lua
version: 0.2.0.1
id: tasty-lua-0.2.0.1-IBkCLkUfmia8JtRZivrgu0
key: tasty-lua-0.2.0.1-IBkCLkUfmia8JtRZivrgu0
license: MIT
copyright: Albert Krewinkel <albert+hslua@zeitkraut.de>
maintainer: albert+hslua@zeitkraut.de
author: Albert Krewinkel
homepage: https://github.com/hslua/tasty-lua
synopsis: Write tests in Lua, integrate into tasty.
description:
    Allow users to define tasty tests from Lua.
category: Foreign
abi: 69beffec8b2a9ee9100d3a6acc6d551b
exposed: True
exposed-modules:
    Test.Tasty.Lua Test.Tasty.Lua.Core Test.Tasty.Lua.Module
    Test.Tasty.Lua.Translate
import-dirs: /usr/lib/ghc-8.6.5/site-local/tasty-lua-0.2.0.1
library-dirs: /usr/lib/ghc-8.6.5/site-local/tasty-lua-0.2.0.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/tasty-lua-0.2.0.1
hs-libraries: HStasty-lua-0.2.0.1-IBkCLkUfmia8JtRZivrgu0
depends:
    base-4.12.0.0 bytestring-0.10.8.2
    file-embed-0.0.11-4IE3sw0bCLQ7xXwEGMUYke
    hslua-1.0.3.1-40ur5CE4aGD2qxUMUcaV3N
    tasty-1.2-L0qrhWDKU2n6IIJu4C6GSU text-1.2.3.1
haddock-interfaces: /usr/share/doc/haskell-tasty-lua/html/tasty-lua.haddock
haddock-html: /usr/share/doc/haskell-tasty-lua/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-tasty-lua-0.2.0.1-2-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-tasty-lua.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: tasty-lua
version: 0.2.0.1
id: tasty-lua-0.2.0.1-BUSymD1MAVWCLw1Y57PW11
key: tasty-lua-0.2.0.1-BUSymD1MAVWCLw1Y57PW11
license: MIT
copyright: Albert Krewinkel <albert+hslua@zeitkraut.de>
maintainer: albert+hslua@zeitkraut.de
author: Albert Krewinkel
homepage: https://github.com/hslua/tasty-lua
synopsis: Write tests in Lua, integrate into tasty.
description:
    Allow users to define tasty tests from Lua.
category: Foreign
abi: 42ad31740c88518490270f28608d4345
exposed: True
exposed-modules:
    Test.Tasty.Lua Test.Tasty.Lua.Core Test.Tasty.Lua.Module
    Test.Tasty.Lua.Translate
import-dirs: /usr/lib/ghc-8.6.5/site-local/tasty-lua-0.2.0.1
library-dirs: /usr/lib/ghc-8.6.5/site-local/tasty-lua-0.2.0.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/tasty-lua-0.2.0.1
hs-libraries: HStasty-lua-0.2.0.1-BUSymD1MAVWCLw1Y57PW11
depends:
    base-4.12.0.0 bytestring-0.10.8.2
    file-embed-0.0.11-4IE3sw0bCLQ7xXwEGMUYke
    hslua-1.0.3.1-CsLJKRioAtG5ktJSmrrnNr
    tasty-1.2.3-AUVOTgx4uuy2lCe0MDaZEJ text-1.2.3.1
haddock-interfaces: /usr/share/doc/haskell-tasty-lua/html/tasty-lua.haddock
haddock-html: /usr/share/doc/haskell-tasty-lua/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
